@@ -85,7 +85,9 @@
 #endif
 #endif /* HAVE_POLL_H */
 
+#ifdef HAVE_SYS_STATVFS_H
 #include <sys/statvfs.h>
+#endif
 
 #ifndef NOSOUND
 
@@ -143,6 +145,13 @@ typedef u_int32_t socklen_t;
 
 #endif /* NOTCP */
 
+#ifdef O_SYNC
+#  define MY_O_SYNC O_SYNC
+#else
+#  ifdef O_FSYNC
+#    define MY_O_SYNC O_FSYNC
+#  endif
+#endif
 
 volatile sig_atomic_t stopit;
 volatile sig_atomic_t signal_report;
@@ -543,10 +552,15 @@ void open_output_file(const struct options *const o
   int mode = 0666;
 
   if (strchr(o->O, 'S')) {
-    flags |= O_SYNC;
+#ifdef MY_O_SYNC
+    flags |= MY_O_SYNC;
     if (o->v > 1) {
       fprintf(stderr, "Using O_SYNC on output file\n");
     }
+#else
+    fprintf(stderr, "Trying to use O_SYNC but this OS doesn't have it\n");
+    exit(2);
+#endif
   }
 
   if (state->using_o_direct) {
@@ -557,6 +571,7 @@ void open_output_file(const struct options *const o
     }
 
     if (!o->user_specified_blocksize) {
+#ifdef HAVE_SYS_STATVFS_H
       struct statvfs statfs;
 
       state->ofd = open(o->o, flags, mode);
@@ -570,6 +585,12 @@ void open_output_file(const struct options *const o
       }
       state->b = statfs.f_bsize;
       close(state->ofd);
+#else
+      fprintf(stderr, "This platform does not have statvfs, you need to "
+	      "specify the blocksize manually with -b, it must match the "
+	      "filesystemblocksize\n");
+      exit(2);
+#endif
     }
   }
 
@@ -934,7 +955,7 @@ void malloc_page_aligned(const struct options *const o
   pmalloc->data = pmalloc->allocated + pagesize 
     - (long)pmalloc->allocated % pagesize;
 
-  if (o->v >=2) {
+  if (o->v >=4) {
     fprintf(stderr, "Page-aligned malloc at %p -> %p\n"
 	    , pmalloc->allocated, pmalloc->data);
   }
